widgets/azure_ad_login_view library
Classes
-
a context for an
AzureADLoginNewTokensHandlerfunction - AzureADLoginNewTokensHandlerContext
-
a context for an
AzureADLoginNewTokensHandlerfunction - AzureADLoginView
- a widget, which handles a Azure AD login
- AzureADLoginViewOptions
-
options for an
AzureADLoginViewwidget instance - AzureADLoginViewOptionsBuilder
-
builder for an
AzureADLoginViewOptionsinstance - AzureADTokens
- stores a access token response from Azure AD
- Defines the parameters of the pending navigation callback.
Enums
- InitialAzureADLoginUri
-
known values which describe the
initialUrlvalue for the underlyingWebViewof anAzureADLoginViewwidget - A decision on how to handle a navigation request.
Typedefs
-
an navigation error handler, which receive the
errorand thenavigationcontext - AzureADLoginNewTokensHandler = NavigationDecision? Function(AzureADLoginNewTokensHandlerContext context)
- handler, which is invoked after access token have been generated